@@ -10,9 +10,11 @@ use Scalar::Util qw(blessed);
 
 BEGIN {
 	$MooseX::XSAccessor::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::XSAccessor::VERSION   = '0.004';
+	$MooseX::XSAccessor::VERSION   = '0.005';
 }
 
+our $LVALUE;
+
 use Moose::Exporter;
 "Moose::Exporter"->setup_import_methods;
 
@@ -158,6 +160,24 @@ using L<MooseX::Attribute::Chained>, and can accelerate those too.
    $obj->foo(1)->_set_bar(2);
    print $obj->dump;
 
+=head2 Lvalue accessors
+
+L<MooseX::XSAccessor> will detect lvalue accessors created with
+L<MooseX::LvalueAttribute> and, by default, skip accelerating them.
+
+However, by setting C<< $MooseX::XSAccessor::LVALUE >> to true
+(preferably using the C<local> Perl keyword), you can force it to
+accelerate those too. This introduces a visible change in behaviour
+though. L<MooseX::LvalueAttribute> accessors normally allow two
+patterns for setting the value:
+
+   $obj->foo = 42;   # as an lvalue
+   $obj->foo(42);    # as a method call
+
+However, once accelerated, they may I<only> be set as an lvalue.
+For this reason, setting C<< $MooseX::XSAccessor::LVALUE >> to true is
+considered an experimental feature.
+
 =head1 HINTS
 
 =over
@@ -225,7 +245,7 @@ However, this is a fatal error in Class::XSAccessor.
 MooseX::XSAccessor does not play nice with attribute traits that alter
 accessor behaviour, or define additional accessors for attributes.
 L<MooseX::SetOnce> is an example thereof. L<MooseX::Attribute::Chained>
-is handled as a special exception.
+is handled as a special case.
 
 =item *
 
